from scapy_helper.utils.hstrip import hstrip


def hhstrip(*args, **kwargs):
    try:
        one_line_hex = hstrip(raw=False)
        if one_line_hex:
            print(one_line_hex)
            print(
                "More information about packet @ PacketHelper.com\nhttps://www.packethelper.com/hex/{}".format(
                    one_line_hex.replace(" ", "")
                )
            )
    except Exception as e:
        print(e)
        print(
            "Copy correctly hexdump and try again or go to https://www.packethelper.com"
        )


if __name__ == "__main__":
    hhstrip()



from unittest import TestCase

from scapy.layers.inet import IP, TCP
from scapy.layers.l2 import Ether

from scapy_helper.helpers.to_dict import to_dict


class TestToDict(TestCase):
    def test_simple_dict(self):
        packet = (
            Ether(dst="ff:ff:ff:ff:ff:ff", src="00:00:00:00:00:00")
            / IP(src="0.0.0.0", dst="127.0.0.1")
            / TCP()
        )
        packet_result = {
            "Ethernet": {
                "src": "00:00:00:00:00:00",
                "dst": "ff:ff:ff:ff:ff:ff",
                "type": 2048,
            }
        }

        to_dict_result = to_dict(packet)

        self.assertTrue(isinstance(to_dict_result, dict))
        self.assertEqual(to_dict_result, packet_result)

    def test_simple_dict_get_second_element(self):
        packet = (
            Ether(dst="ff:ff:ff:ff:ff:ff", src="00:00:00:00:00:00")
            / IP(src="0.0.0.0", dst="127.0.0.1")
            / TCP()
        )
        packet_result = {
            "IP": {
                "frag": 0,
                "src": "0.0.0.0",
                "proto": 6,
                "tos": 0,
                "dst": "127.0.0.1",
                "chksum": None,
                "len": None,
                "options": [],
                "version": 4,
                "flags": None,
                "ihl": None,
                "ttl": 64,
                "id": 1,
            }
        }

        to_dict_result = to_dict(packet, layer=1)  # layer 1 is IP

        self.assertTrue(isinstance(to_dict_result, dict))
        self.assertEqual(to_dict_result, packet_result)



from scapy_helper.chexdump import chexdump
from scapy_helper.compare import Compare
from scapy_helper.helpers.ip import int2ip, ip2int
from scapy_helper.helpers.mac import int2mac, mac2int
from scapy_helper.helpers.to_dict import to_dict
from scapy_helper.helpers.to_list import to_list
from scapy_helper.hexdump import hexdump
from scapy_helper.main import diff, get_hex, hex_equal, show_diff, show_hex, table
from scapy_helper.test_case_extensions.packet_assert import PacketAssert
from scapy_helper.test_case_extensions.pytest_assert import *



__values = (int, float, str, bytes, bool, list, tuple, set, dict)


def _layer2dict(frame):
    temp_dict = {}

    if not getattr(frame, "fields_desc", None):
        return
    for _field in frame.fields_desc:
        value = getattr(frame, _field.name)
        if isinstance(value, type(None)):
            value = None
        elif not isinstance(value, __values):
            value = _layer2dict(value)
        temp_dict[_field.name] = value
    return {frame.name: temp_dict}



from os import getenv

try:
    import pyperclip
except ImportError:
    print("Missing pyperclip: pip install pyperclip")

HEXDUMP_VALUE = """
0000  FF FF FF FF FF FF 00 00 00 00 00 00 08 00 45 00  ..............E.
0010  00 28 00 01 00 00 40 06 7C CD 7F 00 00 01 7F 00  .(....@.|.......
0020  00 01 00 14 00 50 00 00 00 00 00 00 00 00 50 02  .....P........P.
0030  20 00 91 7C 00 00                                 ..|..
"""


def hstrip(raw=True, hexdump=None):
    """
    Clean a Scapies hexdump into more friendly "oneliner"
    :param raw: If False, return oneliner
    :param hexdump: String: If you want to manually transfer series of chars
    :return: String
    """
    if not hexdump:
        striped_value = [
            x.split() for x in pyperclip.paste().split("\n") if x.strip() != ""
        ]
    else:
        striped_value = [x.split() for x in hexdump.split("\n") if x.strip() != ""]

    if getenv("SH_DEBUG", False):
        striped_value = [
            x.split() for x in HEXDUMP_VALUE.split("\n") if x.strip() != ""
        ]

    try:
        index_to_start = int(striped_value[0].index("0000"))
    except ValueError:
        print("Something went wrong. Do you copy entire fragment of hexdump?")
        return

    _list = []
    for x in striped_value:
        _list.append(x[index_to_start + 1 : index_to_start + 17])
    else:
        if len(_list[-1]) < 18:
            _list[-1] = _list[-1][
                :-1
            ]  # remove last element if the list is shorter than 18

    oneliner = " ".join([" ".join(x) for x in _list])
    if not hexdump:
        pyperclip.copy(oneliner)  # copy to the clipboard

    if not raw:
        return oneliner
    return "\n".join([" ".join(x) for x in _list])


if __name__ == "__main__":
    print(hstrip())



from unittest import TestCase

from mock import MagicMock
from scapy.layers.inet import IP
from scapy.layers.l2 import Ether

from scapy_helper.test_case_extensions.packet_assert import PacketAssert


class TestPacketAssert(TestCase, PacketAssert):
    def test_assert_hex_equal(self):
        self.assertHexEqual(
            Ether(dst="ff:ff:ff:ff:ff:ff", src="00:00:00:00:00:00"),
            Ether(dst="ff:ff:ff:ff:ff:ff", src="00:00:00:00:00:00"),
        )

    def test_assert_hex_equal_w_automatic_conversion(self):
        obj = MagicMock()
        obj.hex = MagicMock(return_value="ff ff ff ff ff ff 00 00 00 00 00 00 90 00")

        self.assertHexEqual(
            Ether(dst="ff:ff:ff:ff:ff:ff", src="00:00:00:00:00:00"), obj
        )

    def test_assert_hex_not_equal(self):
        self.assertHexNotEqual(
            Ether(dst="ff:ff:ff:ff:ff:ff", src="00:00:00:00:00:00"),
            Ether(dst="ff:ff:ff:ff:ff:ff", src="00:00:00:00:00:aa"),
        )

    def test_assert_hex_len_equal(self):
        frame = Ether(dst="ff:ff:ff:ff:ff:ff", src="00:00:00:00:00:00") / IP()
        longer_frame = Ether(dst="ff:ff:ff:ff:ff:ff", src="00:00:00:00:00:00") / IP()
        self.assertHexLenEqual(frame, longer_frame)

    def test_assert_hex_len_not_equal(self):
        frame = Ether(dst="ff:ff:ff:ff:ff:ff", src="00:00:00:00:00:00")
        longer_frame = Ether(dst="ff:ff:ff:ff:ff:ff", src="00:00:00:00:00:00") / IP()
        self.assertHexLenNotEqual(frame, longer_frame)

    def test_negative_assert_hex_equal(self):
        with self.assertRaises(AssertionError):
            self.assertHexEqual(
                Ether(dst="ff:ff:ff:ff:ff:ff", src="00:00:00:00:00:00"),
                Ether(dst="ff:ff:ff:ff:ff:ff", src="00:00:00:00:00:aa"),
            )

    def test_negative_assert_hex_not_equal(self):
        with self.assertRaises(AssertionError):
            self.assertHexNotEqual(
                Ether(dst="ff:ff:ff:ff:ff:ff", src="00:00:00:00:00:00"),
                Ether(dst="ff:ff:ff:ff:ff:ff", src="00:00:00:00:00:00"),
            )

    def test_assert_bytes_equal(self):
        with self.assertRaises(AssertionError):
            self.assertBytesEqual(Ether(), Ether(dst="00:00:00:00:00:00"))

    def test_negative_assert_bytes_equal(self):
        self.assertBytesEqual(Ether(), Ether())

    def test_assert_bytes_not_equal(self):
        self.assertBytesNotEqual(Ether(), Ether(dst="00:00:00:00:00:00"))

    def test_negative_bytes_not_equal(self):
        with self.assertRaises(AssertionError):
            self.assertBytesNotEqual(Ether(), Ether())

    def test_assert_hex_different_at_position_zero(self):
        self.assertHexDifferentAt(
            Ether(dst="00:00:00:00:00:00"),
            Ether(dst="01:00:00:00:00:00"),
            positions=0,
            message="Packets should be different on 0 position",
        )

    def test_negative_assert_hex_different_at_position_two(self):
        with self.assertRaises(AssertionError):
            self.assertHexDifferentAt(
                Ether(dst="00:00:00:00:00:00"),
                Ether(dst="01:00:00:00:00:00"),
                positions=2,
                message="Packets should be different on 0 position",
            )

    def test_negative_assert_hex_different_at_more_differences(self):
        with self.assertRaises(AssertionError):
            self.assertHexDifferentAt(
                Ether(dst="00:00:00:00:00:00"),
                Ether(dst="01:01:01:00:00:00"),
                positions=2,
                message="Packets should be different on 0 position",
            )

    def test_assert_hex_different_at_position_list(self):
        self.assertHexDifferentAt(
            Ether(dst="00:00:00:00:00:00"),
            Ether(dst="01:01:00:00:00:00"),
            positions=(0, 1),
            message="Packets should be different on (0, 1) position",
        )

    def test_negative_assert_hex_different_at_position_wrong_list(self):
        with self.assertRaises(AssertionError):
            self.assertHexDifferentAt(
                Ether(dst="00:00:00:00:00:00"),
                Ether(dst="01:01:00:00:00:00"),
                positions=(0, 3),
                message="Packets should be different on (0, 1) position",
            )

    def test_negative_assert_hex_different_at_position_wrong_list_half_correct(self):
        with self.assertRaises(AssertionError):
            self.assertHexDifferentAt(
                Ether(dst="00:00:00:00:00:00"),
                Ether(dst="01:01:00:00:00:00"),
                positions=(0, 1, 2),
                message="Packets should be different on (0, 1) positions",
            )

    def test_negative_assert_hex_different_at_position_hex_not_equal_list_is_subset(
        self,
    ):
        with self.assertRaises(AssertionError):
            self.assertHexDifferentAt(
                Ether(dst="00:00:00:00:00:00"),
                Ether(dst="01:01:01:01:01:01"),
                positions=(0, 1, 2),
                message="Packets should be different on (0-5) positions",
            )



from unittest import TestCase


class TestInterfaceInteroperability(TestCase):
    def test_version_0_1_5(self):
        try:
            from scapy_helper import compare, get_hex, show_diff, show_hex, table
        except ImportError as e:
            self.fail("Import Error: %s" % e)

    def test_version_0_1_11(self):
        try:
            from scapy_helper import (
                Compare,
                get_hex,
                hex_equal,
                show_diff,
                show_hex,
                table,
            )
        except ImportError as e:
            self.fail("Import Error: %s" % e)

    def test_version_0_3_0(self):
        try:
            from scapy_helper import (
                Compare,
                PacketAssert,
                get_hex,
                hex_equal,
                show_diff,
                show_hex,
                table,
            )
        except ImportError as e:
            self.fail("Import Error: %s" % e)



from unittest import TestCase

from scapy.layers.inet import IP, TCP
from scapy.layers.l2 import Ether

from scapy_helper import to_list


class TestToList(TestCase):
    def test_simple_list(self):
        packet = (
            Ether(dst="ff:ff:ff:ff:ff:ff", src="00:00:00:00:00:00")
            / IP(src="0.0.0.0", dst="127.0.0.1")
            / TCP()
        )
        packet_result = [
            {
                "Ethernet": {
                    "src": "00:00:00:00:00:00",
                    "dst": "ff:ff:ff:ff:ff:ff",
                    "type": 2048,
                }
            },
            {
                "IP": {
                    "frag": 0,
                    "src": "0.0.0.0",
                    "proto": 6,
                    "tos": 0,
                    "dst": "127.0.0.1",
                    "chksum": None,
                    "len": None,
                    "options": [],
                    "version": 4,
                    "flags": None,
                    "ihl": None,
                    "ttl": 64,
                    "id": 1,
                }
            },
            {
                "TCP": {
                    "reserved": 0,
                    "seq": 0,
                    "ack": 0,
                    "dataofs": None,
                    "urgptr": 0,
                    "window": 8192,
                    "flags": None,
                    "chksum": None,
                    "dport": 80,
                    "sport": 20,
                    "options": [],
                }
            },
        ]

        to_list_result = to_list(packet)

        self.assertTrue(isinstance(to_list_result, list))
        self.assertEqual(to_list_result, packet_result)



from scapy_helper import PacketAssert


def assert_hex_equal(first, second, message="Hex values are not equal"):
    PacketAssert.assertHexEqual(first, second, message)


def assert_hex_not_equal(first, second, message="Hex values are equal"):
    PacketAssert.assertHexNotEqual(first, second, message)


def assert_hex_len_equal(first, second, message="Hex len is equal"):
    PacketAssert.assertHexLenEqual(first, second, message)


def assert_hex_len_not_equal(first, second, message="Hex len is not equal"):
    PacketAssert.assertHexLenNotEqual(first, second, message)


def assert_bytes_equal(first, second, message="Bytes values are not equal"):
    PacketAssert.assertBytesEqual(first, second, message)


def assert_bytes_not_equal(first, second, message="Bytes values are eqaul"):
    PacketAssert.assertBytesNotEqual(first, second, message)



import unittest

from scapy.layers.inet import IP, UDP
from scapy.layers.l2 import Ether

from scapy_helper.compare import Compare


class TestCompare(unittest.TestCase):
    def setUp(self):
        self.ether = (
            Ether(dst="ff:ff:ff:ff:ff:ff", src="00:00:00:00:00:00")
            / IP(src="192.168.1.1", dst="192.168.1.20", ttl=15)
            / UDP()
        )
        self.c_ether = (
            Ether(dst="ff:ff:ff:ff:ff:ff", src="00:00:00:00:00:00")
            / IP(src="192.168.1.2", dst="192.168.1.20", ttl=20)
            / UDP()
        )

        self.compare = Compare(self.ether, self.c_ether)

    def test_table_diff(self):
        self.compare.table_diff()

    def test_hex(self):
        self.assertEqual(
            self.compare.hex(),
            (
                (
                    "ff ff ff ff ff ff 00 00 00 00 00 00 08 00 45 00 00 1c 00 01 00 00 0f 11"
                    " 28 6b c0 a8 01 01 c0 a8 01 14 00 35 00 35 00 08 7c 0e",
                    "ff ff ff ff ff ff 00 00 00 00 00 00 08 00 45 00 00 1c 00 01 00 00 14 11"
                    " 23 6a c0 a8 01 02 c0 a8 01 14 00 35 00 35 00 08 7c 0d",
                )
            ),
        )

    def test_diff(self):
        self.assertTrue(self.compare.diff(), "diff() should return a difference")

    def test_equal(self):
        self.assertFalse(self.compare.equal(), "equal() should return false")
